package com.ruoyi.postCheck.mapper;

import java.util.List;
import com.ruoyi.postCheck.domain.PostAssessmentRatingOtherInfo;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;

/**
 * 打分表明细(职能互评生产日常)Mapper接口
 *
 * @author csg
 * @date 2024-01-01
 */
public interface PostAssessmentRatingOtherInfoMapper extends BaseMapper<PostAssessmentRatingOtherInfo>
{
    /**
     * 查询打分表明细(职能互评生产日常)
     *
     * @param id 打分表明细(职能互评生产日常)主键
     * @return 打分表明细(职能互评生产日常)
     */
    public PostAssessmentRatingOtherInfo selectPostAssessmentRatingOtherInfoById(Long id);

    /**
     * 查询打分表明细(职能互评生产日常)列表
     *
     * @param postAssessmentRatingOtherInfo 打分表明细(职能互评生产日常)
     * @return 打分表明细(职能互评生产日常)集合
     */
    public List<PostAssessmentRatingOtherInfo> selectPostAssessmentRatingOtherInfoList(PostAssessmentRatingOtherInfo postAssessmentRatingOtherInfo);

    /**
     * 新增打分表明细(职能互评生产日常)
     *
     * @param postAssessmentRatingOtherInfo 打分表明细(职能互评生产日常)
     * @return 结果
     */
    public int insertPostAssessmentRatingOtherInfo(PostAssessmentRatingOtherInfo postAssessmentRatingOtherInfo);

    /**
     * 修改打分表明细(职能互评生产日常)
     *
     * @param postAssessmentRatingOtherInfo 打分表明细(职能互评生产日常)
     * @return 结果
     */
    public int updatePostAssessmentRatingOtherInfo(PostAssessmentRatingOtherInfo postAssessmentRatingOtherInfo);

    /**
     * 删除打分表明细(职能互评生产日常)
     *
     * @param id 打分表明细(职能互评生产日常)主键
     * @return 结果
     */
    public int deletePostAssessmentRatingOtherInfoById(Long id);

    /**
     * 批量删除打分表明细(职能互评生产日常)
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deletePostAssessmentRatingOtherInfoByIds(Long[] ids);
}
